import { DefaultTheme } from "solid-styled-components";
declare type LowercaseCharacter = "a" | "b" | "c" | "d" | "e" | "f" | "g" | "h" | "i" | "j" | "k" | "l" | "m" | "n" | "o" | "p" | "q" | "r" | "s" | "t" | "u" | "v" | "w" | "x" | "y" | "z";
declare type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
declare type NonEmptyString = `${AllCharacter}${string}`;
declare type CSSCustomProperties = `var(--${NonEmptyString})`;
declare type LengthUnit = "vmin" | "vmax" | "vh" | "vw" | "%" | "ch" | "ex" | "em" | "rem" | "in" | "cm" | "mm" | "pt" | "pc" | "px";
export declare type CSSLength = `${number}${LengthUnit}` | CSSCustomProperties;
export declare function checkIsCSSLength(str: string): str is CSSLength;
export interface Spacing {
    none: CSSLength;
    xxs: CSSLength;
    xs: CSSLength;
    sm: CSSLength;
    md: CSSLength;
    mdLg: CSSLength;
    lg: CSSLength;
    lgXl: CSSLength;
    xl: CSSLength;
    xlXXl: CSSLength;
    xxl: CSSLength;
}
export declare const spacing: Spacing;
export declare type BaseTheme = Record<string, CSSLength | string | number>;
declare type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? T["space"] : keyof Spacing;
declare type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
declare type MaybeValue = CSSLength | undefined;
declare type GetSpacingValue = (spacingKey: SpacingOptions, theme?: Partial<BaseTheme>) => MaybeValue;
export declare const getSpacingValue: GetSpacingValue;
declare type MaxWidth = number | CSSLength;
export interface CenterProps {
    maxWidth?: MaxWidth;
    centerText?: boolean;
    centerChildren?: boolean;
}
export declare const Center: ((props: CenterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: CenterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type Basis = CSSLength | number;
export interface ColumnDropProps {
    gutter?: SpacingOptions;
    basis?: Basis;
    noStretchedColumns?: boolean;
}
export declare const ColumnDrop: ((props: ColumnDropProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: ColumnDropProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type RatioString = `${number}/${number}` | `${number} / ${number}`;
declare type Ratio = [number, number] | RatioString;
export interface FrameProps {
    ratio?: Ratio;
    position?: string;
}
export declare const Frame: ((props: FrameProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: FrameProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type MinItemWidth = number | CSSLength;
export interface GridProps {
    gutter?: SpacingOptions;
    minItemWidth?: MinItemWidth;
}
export declare const Grid: ((props: GridProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: GridProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare const justifyMap: {
    readonly start: "flex-start";
    readonly end: "flex-end";
    readonly center: "center";
};
declare const alignMap: {
    readonly stretch: "stretch";
    readonly start: "flex-start";
    readonly end: "flex-end";
    readonly center: "center";
};
export interface InlineClusterProps {
    justify?: keyof typeof justifyMap;
    align?: keyof typeof alignMap;
    gutter: SpacingOptions;
}
export declare const InlineCluster: ((props: InlineClusterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: InlineClusterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type Stretch = "all" | "start" | "end" | number;
declare type SwitchAt = string | number;
export interface InlineProps extends InlineClusterProps {
    stretch?: Stretch;
    switchAt?: SwitchAt;
}
export declare const Inline: ((props: InlineProps & InlineClusterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: InlineProps & InlineClusterProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type PaddingObj = {
    left: SpacingOptions;
} | {
    right: SpacingOptions;
} | {
    top: SpacingOptions;
} | {
    bottom: SpacingOptions;
} | {
    inlineStart: SpacingOptions;
} | {
    inlineEnd: SpacingOptions;
} | {
    blockStart: SpacingOptions;
} | {
    blockEnd: SpacingOptions;
};
declare type PaddingTypes = SpacingOptions | PaddingObj | [SpacingOptions] | [SpacingOptions, SpacingOptions] | [SpacingOptions, SpacingOptions, SpacingOptions] | [SpacingOptions, SpacingOptions, SpacingOptions, SpacingOptions];
export interface PadBoxProps {
    padding: PaddingTypes;
}
export declare const PadBox: ((props: PadBoxProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: PadBoxProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
export interface ReelProps {
    snapType?: "none" | "proximity" | "mandatory";
    gutter: SpacingOptions;
}
export declare const Reel: ((props: ReelProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: ReelProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
export interface StackProps {
    gutter?: SpacingOptions;
}
export declare const Stack: ((props: StackProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => import("solid-js").JSX.Element) & {
    className: (props: StackProps & import("solid-js").JSX.HTMLAttributes<HTMLDivElement>) => string;
};
export {};
